@@ -24,13 +24,21 @@ class ParallelRolling:
     def _get_method(df, name, kwargs):
         return getattr(df.rolling(**kwargs), name)
 
-    def do_method(self, df, workers_queue, name, window_attr, args, kwargs):
-        if name == 'apply':
-            # need to deserialize the function
-            args = (dill.loads(args[0]),)
+    def do_method(self, df, workers_queue, name, serialized_flag, window_attr, args, kwargs):
+        if name in ['apply', 'aggregate', 'agg']:
+            if serialized_flag:
+                # need to deserialize the function
+                args = (dill.loads(args[0]),)
+            elif isinstance(args[0], dict):
+                _axis = df._get_axis_number(window_attr['axis'])
+                if isinstance(df, pd.DataFrame):
+                    func = {k: v for k, v in args[0].items() if k in df._get_axis(1 - _axis)}
+                    args = (func,)
 
         def foo():
             method = self._get_method(df, name, window_attr)
+            if name in ['aggregate', 'agg']:
+                return method(*args, *kwargs['args'], **kwargs['kwargs'])
             return method(*args, **kwargs)
 
         return progress_udf_wrapper(foo, workers_queue, 1)()
@@ -55,12 +63,19 @@ class ParallelRolling:
         return min(self.n_cpu * self.split_factor, data.obj.shape[1 - axis])
 
     def _data_reduce(self, result, data):
+        print(result[0])
         axis, offset = self._get_axis_and_offset(data)
         if offset:
             result = [result[0]] + [s[offset:] for s in result[1:]]
             return pd.concat(result, axis=1 - axis, ignore_index=True)
         return pd.concat(result, axis=1 - axis)
 
+    @staticmethod
+    def _func_serialize(func):
+        if callable(func):
+            return dill.dumps(func), True
+        return func, False
+
     @staticmethod
     def _get_attributes(data):
         attributes = {attribute: getattr(data, attribute) for attribute in data._attributes}
@@ -72,17 +87,30 @@ class ParallelRolling:
     def parallelize_method(self, data, name, executor, *args, **kwargs):
         attributes = self._get_attributes(data)
         workers_queue = Manager().Queue()
+        serialized_flag = False
+        if name in ['apply', 'aggregate', 'agg']:
+            # if func is callable need to serialize it
+            func, serialized_flag = self._func_serialize(args[0])
+            if isinstance(func, dict):
+                _axis = data.obj._get_axis_number(attributes['axis'])
+                if _axis:
+                    data.obj = data.obj.loc[[i for i in func.keys()]]
+                else:
+                    if len(func) == 1:
+                        key = list(func.keys())
+                        data.obj = data.obj[key[0]]
+                    else:
+                        data.obj = data.obj[[i for i in func.keys()]]
+            args = (func,)
         tasks = self._get_split_data(data)
         total = self._get_total_tasks(data)
-        if name == 'apply':
-            # need to serialize the function
-            args = (dill.dumps(args[0]),)
         result = progress_imap(
             partial(self.do_method, workers_queue=workers_queue, args=args, kwargs=kwargs, name=name,
-                    window_attr=attributes),
+                    window_attr=attributes, serialized_flag=serialized_flag),
             tasks, workers_queue, n_cpu=self.n_cpu, disable=self.disable_pr_bar, show_vmem=self.show_vmem,
             total=total, desc=name.upper(), executor=executor,
         )
+        print('done')
         return self._data_reduce(result, data)
 
     def do_parallel(self, name):
@@ -180,16 +208,30 @@ class ParallelRolling:
 
             return p_quantile
 
+        if name == 'cov':
+            @doc(DOC, func=name)
+            def p_cov(data, executor='processes', other=None, pairwise=None, ddof=1, numeric_only=False):
+                return self.parallelize_method(data, name, executor, other=other, pairwise=pairwise, ddof=ddof,
+                                               numeric_only=numeric_only)
+
+            return p_cov
+
         if name == 'apply':
             @doc(DOC, func=name)
             def p_apply(data, func, executor='processes', raw=False, engine=None, engine_kwargs=None, args=None,
                         kwargs=None):
                 return self.parallelize_method(data, name, executor, func, raw=raw, engine=engine,
-                                               engine_kwargs=engine_kwargs,
-                                               args=args, kwargs=kwargs)
+                                               engine_kwargs=engine_kwargs, args=args, kwargs=kwargs)
 
             return p_apply
 
+        if name in ['aggregate', 'agg']:
+            @doc(DOC, func=name)
+            def p_aggregate(data, func, *args, executor='processes', **kwargs):
+                return self.parallelize_method(data, name, executor, func, args=args, kwargs=kwargs)
+
+            return p_aggregate
+
 
 class ParallelWindow(ParallelRolling):
     @staticmethod
@@ -230,14 +272,24 @@ class ParallelWindow(ParallelRolling):
 
 class ParallelGroupbyMixin(ParallelRolling):
 
-    def do_method(self, data, workers_queue, name, window_attr, args, kwargs):
-        if name == 'apply':
-            # need to deserialize the function
-            args = (dill.loads(args[0]),)
+    def do_method(self, data, workers_queue, name, serialized_flag, window_attr, args, kwargs):
+        if name in ['apply', 'aggregate', 'agg']:
+            if serialized_flag:
+                # need to deserialize the function
+                args = (dill.loads(args[0]),)
+            elif isinstance(args[0], dict):
+                df = data[1]
+                _axis = df._get_axis_number(window_attr['axis'])
+                if isinstance(df, pd.DataFrame):
+                    func = {k: v for k, v in args[0].items() if k in df._get_axis(1 - _axis)}
+                    args = (func,)
 
         def foo():
             method = self._get_method(data[1], name, window_attr)
-            result = method(*args, **kwargs)
+            if name in ['aggregate', 'agg']:
+                result = method(*args, *kwargs['args'], **kwargs['kwargs'])
+            else:
+                result = method(*args, **kwargs)
             if isinstance(data[0], tuple):
                 idx = [[i] for i in data[0]] + [result.index.tolist()]
             else:
